@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Client for connecting back to the authmilter server
-our $VERSION = '3.20210825'; # VERSION
+our $VERSION = '3.20210907'; # VERSION
 use Mail::Milter::Authentication::Net::Milter;
 use Data::Dumper;
 use Digest::MD5 qw{ md5_base64 };
@@ -303,8 +303,21 @@ sub process {
     $self->r( $milter->send_end_headers());
 
     my $body = $self->{'message_object'}->body();
-    $milter->send_macros( 'i' => $self->{'queue_id'} );
-    $self->r( $milter->send_body( $body ));
+
+    my $chunk_size = 50000;
+    while ($body) {
+        my $body_chunk;
+        if (length($body) > $chunk_size) {
+            $body_chunk = substr($body,0,$chunk_size);
+            $body = substr($body,$chunk_size);
+        }
+        else {
+            $body_chunk = $body;
+            $body = '';
+        }
+        $milter->send_macros( 'i' => $self->{'queue_id'} );
+        $self->r( $milter->send_body( $body_chunk ));
+    }
 
     $milter->send_macros( 'i' => $self->{'queue_id'} );
     $self->r( $milter->send_end_body());
@@ -350,7 +363,7 @@ Mail::Milter::Authentication::Client - Client for connecting back to the authmil
 
 =head1 VERSION
 
-version 3.20210825
+version 3.20210907
 
 =head1 SYNOPSIS
 
